@@ -16,6 +16,9 @@ class Vote(models.Model):
 class Feedback(models.Model):
     feedback = models.CharField(max_length=1000,blank=True,null=True)
     path = models.CharField(max_length=256,blank=True,null=True)
+    user = models.ForeignKey(auth_models.User)
+    added = models.DateTimeField(auto_now_add=True)
+    extra = models.TextField(default="")
 
     def upvote(self,user,upvote=True):
         vote = Vote(feedback=self,user=user,vote=upvote)
